package cn.com.ty.lift.system.user.service.impl;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.system.user.dao.entity.MTCompanyUser;
import cn.com.ty.lift.system.user.dao.entity.UserAccount;
import cn.com.ty.lift.system.user.dao.entity.UserRole;
import cn.com.ty.lift.system.user.dao.entity.model.MTCompany;
import cn.com.ty.lift.system.user.dao.mapper.MTCompanyUserMapper;
import cn.com.ty.lift.system.user.service.IMTCompanyUserService;
import cn.com.ty.lift.system.user.service.IUserAccountService;
import cn.com.ty.lift.system.user.service.IUserRoleService;
import cn.com.ty.lift.system.utils.ProjectUtils;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * @author huangyuan
 * @date 2019-12-03
 * @description
 */
@Service
public class MTCompanyUserService extends ServiceImpl<MTCompanyUserMapper, MTCompanyUser> implements IMTCompanyUserService {

    @Autowired
    private IUserRoleService userRoleService;

    @Autowired
    private IUserAccountService userAccountService;

    @Override
    @Transactional
    public RestResponse assignRole(MTCompany mtCompany) {
        //获取用户是否已有mtCompanyUser信息。
        MTCompanyUser mtCompanyUser = this.getOne(new QueryWrapper<MTCompanyUser>()
                .eq("mt_company_id", mtCompany.getCompanyId())
                .eq("user_id", mtCompany.getUserId())
        );
        if (mtCompanyUser == null) {
            mtCompanyUser = new MTCompanyUser(mtCompany);
            mtCompanyUser.setMtCompanyId(mtCompany.getCompanyId());
        }
        //保存职业信息
        this.saveOrUpdate(mtCompanyUser);
        //保存用户角色关联信息
        //1.删除原有的关联关系
        UserRole queryUserRole = new UserRole(mtCompany.getUserId(), mtCompany.getRoleId());
        UserRole userRole = userRoleService.getByUserRole(queryUserRole);
        if (userRole != null) {
            boolean deleteUserRoleFlag = userRoleService.removeById(userRole.getId());
            if (!deleteUserRoleFlag) {
                return RestResponse.error(ApiConstants.RESULT_ERROR, "删除原有关联关系失败");
            }
        }
        //保存新的关联关系
        userRole = new UserRole();
        userRole.setCompanyId(mtCompany.getCompanyId());
        userRole.setRoleId(mtCompany.getRoleId());
        userRole.setUserId(mtCompany.getUserId());
        userRoleService.save(userRole);
        return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "分配角色成功");
    }

    @Override
    public RestResponse getCompanyMembers(MTCompany mtCompany) {
        List<MTCompanyUser> mtCompanyUserList = this.list(new QueryWrapper<MTCompanyUser>()
                .eq("mt_company_id", mtCompany.getCompanyId()));
        List<String> userIdList = ProjectUtils.getAttrList(mtCompanyUserList, "userId", null);
        List<UserAccount> userAccountList = (List<UserAccount>) userAccountService.listByIds(userIdList);
        return RestResponse.ok(userAccountList, ApiConstants.RESULT_SUCCESS, "获取团队用户成功");
    }
}
